@@ -1,4 +1,4 @@
-# jhbuild - a build script for GNOME 1.x and 2.x
+# jhbuild - a tool to ease building collections of source packages
 # Copyright (C) 2001-2006  James Henstridge
 # Copyright (C) 2007-2008  Frederic Peters
 #
@@ -41,11 +41,11 @@ _default_jhbuildrc = os.path.join(os.environ['HOME'], '.jhbuildrc')
 
 _known_keys = [ 'moduleset', 'modules', 'skip', 'tags', 'prefix',
                 'partial_build', 'checkoutroot', 'buildroot', 'top_builddir',
-                'autogenargs', 'makeargs', 'nice_build',
+                'autogenargs', 'makeargs', 'nice_build', 'jobs',
                 'installprog', 'repos', 'branches', 'noxvfb', 'xvfbargs',
                 'builddir_pattern', 'module_autogenargs', 'module_makeargs',
                 'interact', 'buildscript', 'nonetwork',
-                'alwaysautogen', 'nobuild', 'makeclean', 'makecheck', 'module_makecheck',
+                'nobuild', 'makeclean', 'makecheck', 'module_makecheck',
                 'use_lib64', 'tinderbox_outputdir', 'sticky_date',
                 'tarballdir', 'pretty_print', 'svn_program', 'makedist',
                 'makedistcheck', 'nonotify', 'notrayicon', 'cvs_program',
@@ -59,7 +59,12 @@ _known_keys = [ 'moduleset', 'modules', 'skip', 'tags', 'prefix',
                 'jhbuildbot_mastercfg', 'use_local_modulesets',
                 'ignore_suggests', 'modulesets_dir', 'mirror_policy',
                 'module_mirror_policy', 'dvcs_mirror_dir', 'build_targets',
-                'cmakeargs', 'module_cmakeargs', 'print_command_pattern' ]
+                'cmakeargs', 'module_cmakeargs', 'print_command_pattern',
+                'static_analyzer', 'module_static_analyzer', 'static_analyzer_template', 'static_analyzer_outputdir',
+
+                # Internal only keys (propagated from command line options)
+                '_internal_noautogen',
+                ]
 
 env_prepends = {}
 def prependpath(envvar, path):
@@ -180,6 +185,9 @@ class Config:
                 raise FatalError(
                     _('Obsolete JHBuild start script, make sure it is removed '
                       'then do run \'make install\''))
+            
+        # Set defaults for internal variables
+        self._config['_internal_noautogen'] = False
 
         env_prepends.clear()
         try:
@@ -260,6 +268,14 @@ class Config:
         if config.get('installprog') and os.path.exists(config['installprog']):
             os.environ['INSTALL'] = config['installprog']
 
+        for path_key in ('checkoutroot', 'buildroot', 'top_builddir',
+                         'tinderbox_outputdir', 'tarballdir', 'copy_dir',
+                         'jhbuildbot_slaves_dir', 'jhbuildbot_dir',
+                         'jhbuildbot_mastercfg', 'modulesets_dir',
+                         'dvcs_mirror_dir', 'static_analyzer_outputdir'):
+            if config.get(path_key):
+                config[path_key] = os.path.expanduser(config[path_key])
+
         # copy known config keys to attributes on the instance
         for name in _known_keys:
             setattr(self, name, config[name])
@@ -395,6 +411,20 @@ class Config:
         xcursordir = os.path.join(self.prefix, 'share', 'icons')
         addpath('XCURSOR_PATH', xcursordir)
 
+        # GST_PLUGIN_PATH
+        for gst in ('gstreamer-1.0', 'gstreamer-0.10'):
+            gstplugindir = os.path.join(self.libdir , gst)
+            if os.path.exists(gstplugindir):
+                addpath('GST_PLUGIN_PATH', gstplugindir)
+
+        # GST_REGISTRY
+        gstregistry = os.path.join(self.prefix, '_jhbuild', 'gstreamer.registry')
+        addpath('GST_REGISTRY', gstregistry)
+
+        # ACLOCAL_PATH
+        aclocalpath = os.path.join(self.prefix, 'share', 'aclocal')
+        addpath('ACLOCAL_PATH', aclocalpath)
+
         # ACLOCAL_FLAGS
         aclocaldir = os.path.join(self.prefix, 'share', 'aclocal')
         if not os.path.exists(aclocaldir):
@@ -533,14 +563,12 @@ class Config:
             options = self.cmdline_options
         else:
             self.cmdline_options = options
-        if hasattr(options, 'autogen') and options.autogen:
-            self.alwaysautogen = True
-        if hasattr(options, 'clean') and (
-                options.clean and not 'clean' in self.build_targets):
-            self.build_targets.insert(0, 'clean')
         if hasattr(options, 'check') and (
                 options.check and not 'check' in self.build_targets):
             self.build_targets.insert(0, 'check')
+        if hasattr(options, 'clean') and (
+                options.clean and not 'clean' in self.build_targets):
+            self.build_targets.insert(0, 'clean')
         if hasattr(options, 'dist') and (
                 options.dist and not 'dist' in self.build_targets):
             self.build_targets.append('dist')
