@@ -1,4 +1,4 @@
-# jhbuild - a build script for GNOME 1.x and 2.x
+# jhbuild - a tool to ease building collections of source packages
 # Copyright (C) 2001-2006  James Henstridge
 # Copyright (C) 2003-2004  Seth Nickell
 #
@@ -59,7 +59,8 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
 
     def __init__(self, config, module_list=None, module_set=None):
         self.orig_modulelist = module_list
-        buildscript.BuildScript.__init__(self, config, module_list, module_set=module_set)
+        self.module_set = jhbuild.moduleset.load(config)
+        buildscript.BuildScript.__init__(self, config, module_list, module_set=self.module_set)
         self.config = config
         gtk.Window.__init__(self)
         self.set_resizable(False)
@@ -75,8 +76,6 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
                     )
         self.set_title('JHBuild')
 
-        self.module_set = jhbuild.moduleset.load(config)
-
         self.create_modules_list_model()
         self.create_ui()
         self.notify = notify.Notify(config)
@@ -268,7 +267,7 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
 
     def on_help_cb(self, *args):
         gtk.show_uri(gtk.gdk.screen_get_default(),
-                'ghelp:jhbuild', gtk.get_current_event_time())
+                'help:jhbuild', gtk.get_current_event_time())
 
     def on_preferences_cb(self, *args):
         if not self.preference_dialog:
@@ -349,6 +348,9 @@ class AppWindow(gtk.Window, buildscript.BuildScript):
         self.build_button.set_sensitive(True)
         self.module_hbox.set_sensitive(True)
 
+    def start_phase(self, module, phase):
+        self.notify.clear()
+
     def start_module(self, module):
         idx = [x.name for x in self.modulelist].index(module)
         self.progressbar.set_fraction((1.0*idx) / len(self.modulelist))
@@ -714,7 +716,6 @@ class PreferencesDialog(gtk.Dialog):
 
         for key, label in (
                 ('nonetwork', _('Disable network access')),
-                ('alwaysautogen', _('Always run autogen.sh')),
                 ('nopoison', _('Don\'t poison modules on failure'))):
             checkbutton = gtk.CheckButton(label)
             checkbutton.set_active(getattr(self.app.config, key))
