@@ -1,4 +1,4 @@
-# jhbuild - a build script for GNOME 1.x and 2.x
+# jhbuild - a tool to ease building collections of source packages
 # Copyright (C) 2001-2006  James Henstridge
 #
 #   __init__.py: package to hold module type defintions
@@ -34,6 +34,7 @@ import logging
 from jhbuild.errors import FatalError, CommandError, BuildStateError, \
              SkipToEnd, UndefinedRepositoryError
 from jhbuild.utils.sxml import sxml
+import jhbuild.utils.fileutils as fileutils
 
 _module_types = {}
 def register_module_type(name, parse_func):
@@ -154,6 +155,7 @@ class Package:
         self.tags = []
         self.moduleset_name = None
         self.supports_install_destdir = False
+        self.supports_parallel_build = True
 
     def __repr__(self):
         return "<%s '%s'>" % (self.__class__.__name__, self.name)
@@ -167,37 +169,37 @@ class Package:
     def get_builddir(self, buildscript):
         raise NotImplementedError
 
-    def _get_destdir(self, buildscript):
+    def get_destdir(self, buildscript):
         return os.path.join(buildscript.config.top_builddir, 'root-%s' % (self.name, ))
 
     def prepare_installroot(self, buildscript):
         assert self.supports_install_destdir
         """Return a directory suitable for use as e.g. DESTDIR with "make install"."""
-        destdir = self._get_destdir(buildscript)
+        destdir = self.get_destdir(buildscript)
         if os.path.exists(destdir):
             shutil.rmtree(destdir)
         os.makedirs(destdir)
         return destdir
 
+    def _clean_la_files_in_dir(self, buildscript, path):
+        for name in os.listdir(path):
+            subpath = os.path.join(path, name)
+            if os.path.isdir(subpath):
+                self._clean_la_files_in_dir(buildscript, subpath)
+            elif name.endswith('.la'):
+                    try:
+                        logging.info(_('Deleting .la file: %r') % (subpath, ))
+                        os.unlink(subpath)
+                    except OSError:
+                        pass
+
     def _clean_la_files(self, buildscript, installroot):
-        """This method removes .la files from the toplevel lib*/
-        directories.  See bug 654013."""
+        """This method removes all .la files. See bug 654013."""
         assert os.path.isabs(installroot)
         assert os.path.isabs(buildscript.config.prefix)
         prefixdir = os.path.join(installroot, buildscript.config.prefix[1:])
         if os.path.isdir(prefixdir):
-            for name in os.listdir(prefixdir):
-                namepath = os.path.join(prefixdir, name)
-                if not (name.startswith('lib') and os.path.isdir(namepath)):
-                    continue
-                for subname in os.listdir(namepath):
-                    subpath = os.path.join(namepath, subname)
-                    if subname.endswith('.la'):
-                        try:
-                            logging.info(_('Deleting toplevel .la file: %r') % (subpath, ))
-                            os.unlink(subpath)
-                        except OSError:
-                            pass
+            self._clean_la_files_in_dir(self, prefixdir)
 
     def _process_install_files(self, installroot, curdir, prefix):
         """Strip the prefix from all files in the install root, and move
@@ -226,17 +228,31 @@ them into the prefix."""
                 os.rmdir(src_path)
             else:
                 num_copied += 1
-                os.rename(src_path, dest_path)
+                try:
+                    os.rename(src_path, dest_path)
+                except OSError, e:
+                    logging.error(_('Failed to rename %(src)r to %(dest)r: %(msg)s') %
+                                  {'src': src_path,
+                                   'dest': dest_path,
+                                   'msg': e.message})
+                    raise
+                    
         return num_copied
 
     def process_install(self, buildscript, revision):
         assert self.supports_install_destdir
-        destdir = self._get_destdir(buildscript)
+        destdir = self.get_destdir(buildscript)
         self._clean_la_files(buildscript, destdir)
 
         stripped_prefix = buildscript.config.prefix[1:]
 
-        buildscript.moduleset.packagedb.add(self.name, revision or '', destdir)
+        previous_entry = buildscript.moduleset.packagedb.get(self.name)
+        if previous_entry:
+            previous_contents = previous_entry.get_manifest()
+        else:
+            previous_contents = None
+
+        new_contents = fileutils.accumulate_dirtree_contents(destdir)
 
         install_succeeded = False
         save_broken_tree = False
@@ -284,6 +300,27 @@ them into the prefix."""
 
         if not install_succeeded:
             raise CommandError(_("Module failed to install into DESTDIR %(dest)r") % {'dest': broken_name})
+        else:
+            absolute_new_contents = map(lambda x: '/' + x, new_contents)
+            to_delete = []
+            if previous_contents is not None:
+                for path in previous_contents:
+                    if path not in absolute_new_contents:
+                        to_delete.append(path)
+                # Ensure we're only attempting to delete files in the prefix
+                to_delete = fileutils.filter_files_by_prefix(self.config, to_delete)
+                logging.info(_('%d files remaining from previous build') % (len(to_delete),))
+                for (path, was_deleted, error_string) in fileutils.remove_files_and_dirs(to_delete, allow_nonempty_dirs=True):
+                    if was_deleted:
+                        logging.info(_('Deleted: %(file)r') % { 'file': path, })
+                    elif error_string is None:
+                        # We don't warn on not-empty directories
+                        pass
+                    else:
+                        logging.warn(_("Failed to delete no longer installed file %(file)r: %(msg)s") % { 'file': path,
+                                                                                                          'msg': error_string})
+
+            buildscript.moduleset.packagedb.add(self.name, revision or '', absolute_new_contents)
 
     def get_revision(self):
         return self.branch.tree_id()
@@ -390,6 +427,7 @@ them into the prefix."""
         instance = cls(name)
         instance.branch = get_branch(node, repositories, default_repo, config)
         instance.dependencies, instance.after, instance.suggests = get_dependencies(node)
+        instance.supports_parallel_build = (node.getAttribute('supports-parallel-builds') != 'no')
         pkg_config = find_first_child_node_content(node, 'pkg-config')
         if pkg_config != '':
             instance.pkg_config = pkg_config
@@ -457,4 +495,3 @@ register_module_type('metamodule', parse_metamodule)
 register_lazy_module_type('autotools', 'jhbuild.modtypes.autotools')
 register_lazy_module_type('cvsmodule', 'jhbuild.modtypes.autotools')
 register_lazy_module_type('svnmodule', 'jhbuild.modtypes.autotools')
-register_lazy_module_type('archmodule', 'jhbuild.modtypes.autotools')
