@@ -1,4 +1,4 @@
-# jhbuild - a build script for GNOME 1.x and 2.x
+# jhbuild - a tool to ease building collections of source packages
 # Copyright (C) 2011  Colin Walters <walters@verbum.org>
 #
 #   systeminstall.py - Use system-specific means to acquire dependencies
@@ -42,7 +42,7 @@ def get_installed_pkgconfigs(config):
     for pkg in pkgs:
         args = ['pkg-config', '--modversion']
         args.append(pkg)
-        proc = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=open('/dev/null'),
+        proc = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                                 close_fds=True, env=config.get_original_environment())
         stdout = proc.communicate()[0]
         proc.wait()
